@@ -7,8 +7,12 @@ import sys
 
 import pytest
 
-from object_validator import Object, Bool, Integer, Float, String, List, Dict, DictScheme
-from object_validator import InvalidTypeError, MissingParameterError, UnknownParameterError, ParameterAlreadyExistsError
+from object_validator import (
+    Object, Bool, Integer, Float,
+    String, List, Dict, DictScheme)
+from object_validator import (
+    InvalidTypeError, InvalidListLength, MissingParameterError,
+    UnknownParameterError, ParameterAlreadyExistsError)
 
 PY2 = sys.version_info < (3,)
 if PY2:
@@ -20,7 +24,6 @@ class ToInt(Object):
         return int(obj)
 
 
-
 def test_list_empty():
     _validate([], List(Bool()))
 
@@ -55,6 +58,19 @@ def test_list_invalid_element_type():
     assert error.object_type == int
 
 
+def test_list_min_max_length_valid():
+    _validate([1, 2, 3], List(min_length=1, max_length=3))
+
+
+def test_list_min_length_invalid():
+    with pytest.raises(InvalidListLength):
+        _validate([1, 2, 3], List(min_length=4, max_length=3))
+
+
+def test_list_max_length_invalid():
+    with pytest.raises(InvalidListLength):
+        _validate([1, 2, 3], List(min_length=1, max_length=2))
+
 
 def test_dict_default():
     _validate({
@@ -74,23 +90,23 @@ def test_dict_key_value():
 
 def test_dict_key_modification():
     _validate_modification(
-        { "1": 10, "2": 20 }, Dict(ToInt(), Integer()), { 1: 10, 2: 20 })
+        {"1": 10, "2": 20}, Dict(ToInt(), Integer()), {1: 10, 2: 20})
 
 
 def test_dict_value_modification():
     _validate_modification(
-        { 1: "10", 2: "20" }, Dict(Integer(), ToInt()), { 1: 10, 2: 20 })
+        {1: "10", 2: "20"}, Dict(Integer(), ToInt()), {1: 10, 2: 20})
 
 
 def test_dict_key_value_modification():
     _validate_modification(
-        { "1": "10", "2": "20" }, Dict(ToInt(), ToInt()), { 1: 10, 2: 20 })
+        {"1": "10", "2": "20"}, Dict(ToInt(), ToInt()), {1: 10, 2: 20})
 
 
 def test_dict_invalid_key_modification():
     error = pytest.raises(ParameterAlreadyExistsError, lambda:
         _validate_modification(
-            { 1: "10", "1": "100" }, Dict(ToInt(), None), { 1: 10 })
+            {1: "10", "1": "100"}, Dict(ToInt(), None), {1: 10})
     ).value
 
     assert error.object_name == "[1]"
@@ -120,7 +136,6 @@ def test_dict_invalid_value_scheme():
     assert error.object_type == int
 
 
-
 def test_dict_scheme_empty():
     _validate({}, DictScheme({}))
 
@@ -149,21 +164,21 @@ def test_dict_scheme_with_ignore_unknown():
 
 def test_dict_scheme_with_delete_unknown():
     _validate_modification(
-        {"known_key": 10, "unknown_key": 10,},
+        {"known_key": 10, "unknown_key": 10},
         DictScheme({"known_key": Integer()}, delete_unknown=True),
         {"known_key": 10})
 
 
 def test_dict_scheme_modification():
     _validate_modification(
-        { "1": "10", "2": "20", "3": "30" },
-        DictScheme({ "1": ToInt(), "2": String(), "3": ToInt() }),
-        { "1": 10, "2": "20", "3": 30 })
+        {"1": "10", "2": "20", "3": "30"},
+        DictScheme({"1": ToInt(), "2": String(), "3": ToInt()}),
+        {"1": 10, "2": "20", "3": 30})
 
 
 def test_dict_scheme_invalid_type():
     error = pytest.raises(InvalidTypeError, lambda:
-       _validate([],  DictScheme({}))
+        _validate([], DictScheme({}))
     ).value
 
     assert error.object_name == ""
@@ -191,7 +206,6 @@ def test_dict_scheme_missing_parameter():
     assert error.object_name == "[1]"
 
 
-
 def _validate(obj, scheme):
     obj_copy = copy.deepcopy(obj)
 
